@@ -38,11 +38,6 @@ class Decompressor():
             download_stream = await blob_client.download_blob()
             await afp.write(await download_stream.readall())
 
-    async def upload_decompressed_files(self, container_name, dest_dir, decompression_dir):
-        files_to_upload = self.get_files_to_upload(decompression_dir)
-        for file in files_to_upload:
-            await self.upload_decompressed_file(file, container_name, dest_dir)      
-
     def get_files_to_upload(self, decompression_dir):
         files = []
         # r=root, d=directories, f = files
@@ -52,17 +47,21 @@ class Decompressor():
 
         return files
 
-    async def upload_decompressed_file(self, file, container_name, dest_dir):
+    async def upload_decompressed_files(self, container_name, dest_dir, decompression_dir):
+        files_to_upload = self.get_files_to_upload(decompression_dir)
+
         blob_service_client = BlobServiceClient.from_connection_string(self.conn_str)
-
-        blob_name = os.path.basename(file)
-
         async with blob_service_client:
-            blob_client = blob_service_client.get_blob_client(container=container_name, blob="{}/{}".format(dest_dir, blob_name))
-
-            async with async_open(file, "rb") as afp:
-                await blob_client.upload_blob(await afp.read(), overwrite=True)      
+            for file in files_to_upload:
+                await self.upload_decompressed_file(blob_service_client, file, container_name, dest_dir)   
+    
+    async def upload_decompressed_file(self, blob_service_client, file, container_name, dest_dir):
+        blob_name = os.path.basename(file)
+        blob_client = blob_service_client.get_blob_client(container=container_name, blob="{}/{}".format(dest_dir, blob_name))
 
+        async with async_open(file, "rb") as afp:
+            await blob_client.upload_blob(await afp.read(), overwrite=True)   
+            
     def decompress(self, downloaded_file):   
         decompression_dir = os.path.splitext(downloaded_file)[0]
 
